/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.database.data;

import java.io.Serializable;

import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;

@Entity( name = "UserApplicationData" )
@Table( name = "dv_user_application" )
public class UserApplicationData
    implements Serializable
{

    private static final long serialVersionUID = 6455507814254304669L;

    public static final long NEW_USER_APPLICATION = 0;

    public static final long UNDEFINED_USER_APPLICATION = -1;

    @Id
    @GeneratedValue( strategy = GenerationType.AUTO )
    private Long id;

    @ManyToOne
    @JoinColumn( name = "user_id", referencedColumnName = "id", nullable = false )
    private UserData userData;

    @ManyToOne
    @JoinColumn( name = "application_id", referencedColumnName = "id", nullable = false )
    private ApplicationData applicationData;

    public UserApplicationData()
    {
        // nothing to do
    }

    public UserApplicationData( long id, UserData userData, ApplicationData applicationData )
    {
        setId( id );
        setUserData( userData );
        setApplicationData( applicationData );
    }

    public Long getId()
    {
        return id;
    }

    public void setId( Long id )
    {
        this.id = id;
    }

    public UserData getUserData()
    {
        return userData;
    }

    public void setUserData( UserData userData )
    {
        this.userData = userData;
    }

    public ApplicationData getApplicationData()
    {
        return applicationData;
    }

    public void setApplicationData( ApplicationData applicationData )
    {
        this.applicationData = applicationData;
    }

    @Override
    public int hashCode()
    {
        final int prime = 31;
        int result = 1;
        result = prime * result + ( ( id == null ) ? 0 : id.hashCode() );
        return result;
    }

    @Override
    public boolean equals( Object obj )
    {
        if ( this == obj )
        {
            return true;
        }
        if ( obj == null )
        {
            return false;
        }
        if ( !( obj instanceof UserApplicationData ) )
        {
            return false;
        }
        UserApplicationData other = (UserApplicationData) obj;
        if ( id == null )
        {
            if ( other.id != null )
            {
                return false;
            }
        }
        else if ( !id.equals( other.id ) )
        {
            return false;
        }
        return true;
    }

}
