/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.database.data;

import java.io.Serializable;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;

@Entity( name = "UserSessionApplicationData" )
@Table( name = "dv_user_session_application" )
public class UserSessionApplicationData
    implements Serializable
{

    private static final long serialVersionUID = 1537864382300721706L;

    public static final long NEW_USER_SESSION_APPLICATION = 0;

    public static final long UNDEFINED_USER_SESSION_APPLICATION = -1;

    @Id
    @GeneratedValue( strategy = GenerationType.AUTO )
    private Long id;

    @Column( name = "user_session_id", nullable = false )
    private Long userSessionId;

    @Column( name = "application_id", nullable = false )
    private Long applicationId;

    @Column( name = "window_id", nullable = false )
    private Integer windowId;

    @Column( name = "user_id", nullable = false )
    private Long userId;

    public UserSessionApplicationData()
    {
        // nothing to do
    }

    public UserSessionApplicationData( long id, long userSessionId, long applicationId, int windowId, long userId )
    {
        setId( id );
        setUserSessionId( userSessionId );
        setApplicationId( applicationId );
        setWindowId( windowId );
        setUserId( userId );
    }

    public Long getId()
    {
        return id;
    }

    public void setId( Long id )
    {
        this.id = id;
    }

    public Long getUserSessionId()
    {
        return userSessionId;
    }

    public void setUserSessionId( Long userSessionId )
    {
        this.userSessionId = userSessionId;
    }

    public Long getApplicationId()
    {
        return applicationId;
    }

    public void setApplicationId( Long applicationId )
    {
        this.applicationId = applicationId;
    }

    public Integer getWindowId()
    {
        return windowId;
    }

    public void setWindowId( Integer windowId )
    {
        this.windowId = windowId;
    }

    public Long getUserId()
    {
        return userId;
    }

    public void setUserId( Long userId )
    {
        this.userId = userId;
    }

    @Override
    public int hashCode()
    {
        final int prime = 31;
        int result = 1;
        result = prime * result + ( ( applicationId == null ) ? 0 : applicationId.hashCode() );
        result = prime * result + ( ( id == null ) ? 0 : id.hashCode() );
        result = prime * result + ( ( userId == null ) ? 0 : userId.hashCode() );
        result = prime * result + ( ( userSessionId == null ) ? 0 : userSessionId.hashCode() );
        result = prime * result + ( ( windowId == null ) ? 0 : windowId.hashCode() );
        return result;
    }

    @Override
    public boolean equals( Object obj )
    {
        if ( this == obj )
        {
            return true;
        }
        if ( obj == null )
        {
            return false;
        }
        if ( !( obj instanceof UserSessionApplicationData ) )
        {
            return false;
        }
        UserSessionApplicationData other = (UserSessionApplicationData) obj;
        if ( applicationId == null )
        {
            if ( other.applicationId != null )
            {
                return false;
            }
        }
        else if ( !applicationId.equals( other.applicationId ) )
        {
            return false;
        }
        if ( id == null )
        {
            if ( other.id != null )
            {
                return false;
            }
        }
        else if ( !id.equals( other.id ) )
        {
            return false;
        }
        if ( userId == null )
        {
            if ( other.userId != null )
            {
                return false;
            }
        }
        else if ( !userId.equals( other.userId ) )
        {
            return false;
        }
        if ( userSessionId == null )
        {
            if ( other.userSessionId != null )
            {
                return false;
            }
        }
        else if ( !userSessionId.equals( other.userSessionId ) )
        {
            return false;
        }
        if ( windowId == null )
        {
            if ( other.windowId != null )
            {
                return false;
            }
        }
        else if ( !windowId.equals( other.windowId ) )
        {
            return false;
        }
        return true;
    }

}
