/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.info;

import org.apache.commons.lang3.StringUtils;

public enum KeyboardLayout
{

    AF( "Afghani", "af" ),
    AL( "Albanian", "al" ),
    AM( "Armenian", "am" ),
    ARA( "Arabic", "ara" ),
    AT( "German (Austria)", "at" ),
    AU( "English (Australian)", "au" ),
    AZ( "Azerbaijani", "az" ),
    BA( "Bosnian", "ba" ),
    BD( "Bangla", "bd" ),
    BE( "Belgian", "be" ),
    BG( "Bulgarian", "bg" ),
    BR( "Portuguese (Brazil)", "br" ),
    BRAI( "Braille", "brai" ),
    BT( "Dzongkha", "bt" ),
    BW( "Tswana", "bw" ),
    BY( "Belarusian", "by" ),
    CA( "French (Canada)", "ca" ),
    CD( "French (Democratic Republic of the Congo)", "cd" ),
    CH( "German (Switzerland)", "ch" ),
    CM( "English (Cameroon)", "cm" ),
    CN( "Chinese", "cn" ),
    CZ( "Czech", "cz" ),
    DE( "German", "de" ),
    DK( "Danish", "dk" ),
    DZ( "Berber (Algeria, Latin)", "dz" ),
    EE( "Estonian", "ee" ),
    EPO( "Esperanto", "epo" ),
    ES( "Spanish", "es" ),
    ET( "Amharic", "et" ),
    FI( "Finnish", "fi" ),
    FO( "Faroese", "fo" ),
    FR( "French", "fr" ),
    GB( "English (UK)", "gb" ),
    GE( "Georgian", "ge" ),
    GH( "English (Ghana)", "gh" ),
    GN( "French (Guinea)", "gn" ),
    GR( "Greek", "gr" ),
    HR( "Croatian", "hr" ),
    HU( "Hungarian", "hu" ),
    ID( "Indonesian (Arab Melayu, phonetic)", "id" ),
    IE( "Irish", "ie" ),
    IL( "Hebrew", "il" ),
    IN( "Indian", "in" ),
    IQ( "Iraqi", "iq" ),
    IR( "Persian", "ir" ),
    IS( "Icelandic", "is" ),
    IT( "Italian", "it" ),
    JP( "Japanese", "jp" ),
    JV( "Indonesian (Javanese)", "jv" ),
    KE( "Swahili (Kenya)", "ke" ),
    KG( "Kyrgyz", "kg" ),
    KH( "Khmer (Cambodia)", "kh" ),
    KR( "Korean", "kr" ),
    KZ( "Kazakh", "kz" ),
    LA( "Lao", "la" ),
    LATAM( "Spanish (Latin American)", "latam" ),
    LK( "Sinhala (phonetic)", "lk" ),
    LT( "Lithuanian", "lt" ),
    LV( "Latvian", "lv" ),
    MA( "Arabic (Morocco)", "ma" ),
    MAO( "Maori", "mao" ),
    MD( "Moldavian", "md" ),
    ME( "Montenegrin", "me" ),
    MK( "Macedonian", "mk" ),
    ML( "Bambara", "ml" ),
    MM( "Burmese", "mm" ),
    MN( "Mongolian", "mn" ),
    MT( "Maltese", "mt" ),
    MV( "Dhivehi", "mv" ),
    MY( "Malay (Jawi, Arabic Keyboard)", "my" ),
    NEC_VNDR_JP( "Japanese (PC-98)", "nec_vndr/jp" ),
    NG( "English (Nigeria)", "ng" ),
    NL( "Dutch", "nl" ),
    NO( "Norwegian", "no" ),
    NP( "Nepali", "np" ),
    PH( "Filipino", "ph" ),
    PK( "Urdu (Pakistan)", "pk" ),
    PL( "Polish", "pl" ),
    PT( "Portuguese", "pt" ),
    RO( "Romanian", "ro" ),
    RS( "Serbian", "rs" ),
    RU( "Russian", "ru" ),
    SE( "Swedish", "se" ),
    SI( "Slovenian", "si" ),
    SK( "Slovak", "sk" ),
    SN( "Wolof", "sn" ),
    SY( "Arabic (Syria)", "sy" ),
    TG( "French (Togo)", "tg" ),
    TH( "Thai", "th" ),
    TJ( "Tajik", "tj" ),
    TM( "Turkmen", "tm" ),
    TR( "Turkish", "tr" ),
    TW( "Taiwanese", "tw" ),
    TZ( "Swahili (Tanzania)", "tz" ),
    UA( "Ukrainian", "ua" ),
    US( "English (US)", "us" ),
    UZ( "Uzbek", "uz" ),
    VN( "Vietnamese", "vn" ),
    ZA( "English (South Africa)", "za" );

    public static final KeyboardLayout DEFAULT_LAYOUT = US;

    private String layout;

    private String layoutCode;

    private KeyboardLayout( String layout, String layoutCode )
    {
        this.layout = layout;
        this.layoutCode = layoutCode;
    }

    public static final KeyboardLayout getKeyboardLayout( String layoutCode )
    {
        for ( KeyboardLayout keyboardLayout : values() )
        {
            if ( StringUtils.equalsIgnoreCase( keyboardLayout.getLayoutCode(), layoutCode ) )
            {
                return keyboardLayout;
            }
        }
        return DEFAULT_LAYOUT;
    }

    public String getLayout()
    {
        return layout;
    }

    public String getLayoutCode()
    {
        return layoutCode;
    }

}
