/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.runners;

import java.util.Calendar;

public abstract class CheckBrowserHealthRunner
    implements Runnable
{

    private static final int CHECK_BROWSER_TIMEOUT = 15000; // milliseconds

    private long browserTime = 0;

    private long browserTimeout = 0;

    private long sessionTime = 0;

    private long sessionTimeout = 0;

    public CheckBrowserHealthRunner( long sessionTimeout )
    {
        Calendar calendar = Calendar.getInstance();
        setBrowserTime( calendar.getTimeInMillis() );
        setBrowserTimeout( CHECK_BROWSER_TIMEOUT );
        setSessionTime( calendar.getTimeInMillis() );
        setSessionTimeout( sessionTimeout );
    }

    public abstract void checkBrowser();

    public abstract void closeBrowser( boolean showMesage );

    @Override
    public void run()
    {
        Calendar currentTime = Calendar.getInstance();
        if ( Math.abs( currentTime.getTimeInMillis() - getBrowserTime() ) > getBrowserTimeout() )
        {
            closeBrowser( false );
        }
        else if ( Math.abs( currentTime.getTimeInMillis() - getSessionTime() ) > getSessionTimeout() )
        {
            closeBrowser( true );
        }
        else
        {
            checkBrowser();
        }
    }

    public long getBrowserTime()
    {
        return browserTime;
    }

    public void setBrowserTime( long browserTime )
    {
        this.browserTime = browserTime;
    }

    public long getBrowserTimeout()
    {
        return browserTimeout;
    }

    public void setBrowserTimeout( long browserTimeout )
    {
        this.browserTimeout = browserTimeout;
    }

    public long getSessionTime()
    {
        return sessionTime;
    }

    public void setSessionTime( long sessionTime )
    {
        this.sessionTime = sessionTime;
    }

    public long getSessionTimeout()
    {
        return sessionTimeout;
    }

    public void setSessionTimeout( long sessionTimeout )
    {
        this.sessionTimeout = sessionTimeout;
    }

}
