/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.runners;

import java.util.concurrent.TimeUnit;

import org.dussan.vaadin.dvirtual.client.VirtualClient;

public abstract class CloseDialogChildAppConnectingUtilRunner
    implements Runnable
{

    private static final int MAX_WAIT_INTERVAL = 30000; // milliseconds

    private static final int SLEEP_INTERVAL = 50; // milliseconds

    private static final int SLEEP_MAX_INTERVAL = 1500; // milliseconds

    private VirtualClient virtualClient = null;

    public CloseDialogChildAppConnectingUtilRunner( VirtualClient virtualClient )
    {
        this.virtualClient = virtualClient;
    }

    public abstract void closeDialog();

    @Override
    public void run()
    {
        try
        {
            for ( int timer = 0; timer < MAX_WAIT_INTERVAL; timer += SLEEP_INTERVAL )
            {
                TimeUnit.MILLISECONDS.sleep( SLEEP_INTERVAL );
                if ( virtualClient.getVirtualUtil()
                                  .isDrawingStarted()
                    || virtualClient.isDrawingStartedInAllDialogOrNormalWindows() )
                {
                    virtualClient.getVirtualUtil()
                                 .setDrawingStarted( true );
                    break;
                }
            }
            TimeUnit.MILLISECONDS.sleep( SLEEP_MAX_INTERVAL ); // DON'T REMOVE
        }
        catch ( InterruptedException exception )
        {
            Thread.currentThread()
                  .interrupt();
        }
        closeDialog();
    }

}
