/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.runners;

import java.util.concurrent.TimeUnit;

import org.dussan.vaadin.dvirtual.utils.VirtualUtil;

public abstract class DetachServerRunner
    implements Runnable
{

    private static final int MAX_WAIT_INTERVAL = 10000; // milliseconds

    private static final int SLEEP_INTERVAL = 50; // milliseconds

    private VirtualUtil virtualUtil = null;

    public DetachServerRunner( VirtualUtil virtualUtil )
    {
        this.virtualUtil = virtualUtil;
    }

    @Override
    public void run()
    {
        try
        {
            TimeUnit.MILLISECONDS.sleep( SLEEP_INTERVAL );
            for ( int timer = 0; timer < MAX_WAIT_INTERVAL; timer += SLEEP_INTERVAL )
            {
                TimeUnit.MILLISECONDS.sleep( SLEEP_INTERVAL );
                if ( virtualUtil.isNotConnectionToServerActive() && virtualUtil.isNotServerConnected() && virtualUtil.isNotRunningApplicationInClosingProcess() )
                {
                    break;
                }
            }
        }
        catch ( InterruptedException exception )
        {
            Thread.currentThread()
                  .interrupt();
        }
        serverDetached();
    }

    public abstract void serverDetached();

}
