/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.utils;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;

import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang3.ArrayUtils;

public class ConverterUtil
    implements Serializable
{

    private static final long serialVersionUID = 7881248268978835379L;

    private ConverterUtil()
    {
        // nothing to do
    }

    public static boolean toBoolean( Object value )
    {
        if ( value instanceof Boolean )
        {
            return ( (boolean) value );
        }
        else if ( value instanceof Number )
        {
            return ( ( (Number) value ).intValue() != 0 );
        }
        return false;
    }

    public static byte[] toByteArray( Object value )
    {
        if ( value instanceof ArrayList )
        {
            return ArrayUtils.toString( value )
                             .getBytes();
        }
        else
        {
            return ( (byte[]) value );
        }
    }

    public static int toInt( Object value )
    {
        return ( ( (Number) value ).intValue() );
    }

    public static long toLong( Object value )
    {
        return ( ( (Number) value ).longValue() );
    }

    public static short toShort( Object value )
    {
        return ( ( (Number) value ).shortValue() );
    }

    @SuppressWarnings( "unchecked" )
    public static Map<String, String> toMap( Object value )
    {
        Map<String, String> map = new HashMap<>();
        Map<String, Object> values = (Map<String, Object>) value;
        if ( MapUtils.isNotEmpty( values ) )
        {
            for ( Entry<String, Object> entry : values.entrySet() )
            {
                map.put( entry.getKey(), toString( entry.getValue() ) );
            }
        }
        return map;
    }

    public static String toString( Object value )
    {
        if ( value instanceof Byte )
        {
            return ( value.toString() );
        }
        else if ( value instanceof byte[] )
        {
            return ( new String( (byte[]) value ) );
        }
        else
        {
            return ( value.toString() );
        }
    }

}
