/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.xpra.info;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import org.apache.commons.lang3.StringUtils;

public enum FullCscMode
{

    H264( "h264", FullCscMode.YUV420P ),
    H264_MP4( "h264+mp4", FullCscMode.YUV420P ),
    WEBP( "webp", "BGRX", "BGRA" ),
    JPEG( "jpeg", "BGRX", "BGRA", "BGR", "RGBX", "RGBA", "RGB", "YUV420P" ),
    // JPEG( "jpeg", "BGRX", "BGRA", "BGR", "RGBX", "RGBA", "RGB", "YUV420P", "YUV422P", "YUV444P" ),
    UNDEFINED( "undefined", "undefined" );

    private static final String YUV420P = "YUV420P";

    private String[] modes;

    private String name;

    FullCscMode()
    {
        name = getName();
        modes = getModes();
    }

    FullCscMode( String name, String... modes )
    {
        this.name = name;
        this.modes = modes;
    }

    public static FullCscMode getCscMode( String name )
    {
        for ( FullCscMode mode : FullCscMode.values() )
        {
            if ( StringUtils.equalsIgnoreCase( mode.getName(), name ) )
            {
                return mode;
            }
        }
        return UNDEFINED;
    }

    public static FullCscMode[] getAllCscModes()
    {
        List<FullCscMode> modes = new ArrayList<>();
        for ( FullCscMode mode : FullCscMode.values() )
        {
            if ( !mode.equals( UNDEFINED ) )
            {
                modes.add( mode );
            }
        }
        return modes.toArray( FullCscMode[]::new );
    }

    public static Map<String, List<String>> toStringMap( FullCscMode[] modes )
    {
        Map<String, List<String>> modeMap = new HashMap<>();
        if ( Objects.nonNull( modes ) && modes.length > 0 )
        {
            for ( FullCscMode mode : modes )
            {
                if ( !mode.equals( UNDEFINED ) )
                {
                    modeMap.put( mode.getName(), Arrays.asList( mode.getModes() ) );
                }
            }
        }
        return modeMap;
    }

    public String getName()
    {
        return name;
    }

    public String[] getModes()
    {
        return modes;
    }

    @Override
    public String toString()
    {
        return name;
    }

}
