/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.packets.client;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.dussan.vaadin.dvirtual.xpra.packets.ClientPacket;
import org.dussan.vaadin.dvirtual.xpra.packets.PacketType;

public class ClientKeyActionPacket
    extends ClientPacket
{

    private static final long serialVersionUID = 4453314058167930717L;

    private boolean keyPressed = false;

    private int group = 0;

    private int keyCode = 0;

    private int keyValue = 0;

    private int windowId = 0;

    private String keyName = null;

    private String keyString = null;

    private List<String> modifiers = new ArrayList<>();

    public ClientKeyActionPacket()
    {
        super( PacketType.Client.KEY_ACTION.toString() );
    }

    public ClientKeyActionPacket( int windowId, int keyCode, int keyValue, String keyName, String keyString, List<String> modifiers, boolean keyPressed )
    {
        super( PacketType.Client.KEY_ACTION.toString() );
        this.windowId = windowId;
        this.keyCode = keyCode;
        this.keyValue = keyValue;
        this.keyName = keyName;
        this.keyString = keyString;
        this.modifiers = modifiers;
        this.keyPressed = keyPressed;
    }

    public boolean getKeyPressed()
    {
        return keyPressed;
    }

    public int getGroup()
    {
        return group;
    }

    public int getKeyCode()
    {
        return keyCode;
    }

    public int getKeyValue()
    {
        return keyValue;
    }

    public int getWindowId()
    {
        return windowId;
    }

    public String getKeyName()
    {
        return keyName;
    }

    public String getKeyString()
    {
        return keyString;
    }

    public List<String> getModifiers()
    {
        return modifiers;
    }

    @Override
    public void packPacket( Collection<Object> packetData )
    {
        packetData.add( getPacketType() );
        packetData.add( getWindowId() );
        packetData.add( getKeyName() );
        packetData.add( getKeyPressed() );
        packetData.add( getModifiers() );
        packetData.add( getKeyValue() );
        packetData.add( getKeyString() );
        packetData.add( getKeyCode() );
        packetData.add( getGroup() );
    }

}
