/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.packets.client;

import java.util.Collection;
import org.dussan.vaadin.dvirtual.xpra.packets.ClientPacket;
import org.dussan.vaadin.dvirtual.xpra.packets.PacketType;

public class ClientMapWindowPacket
    extends ClientPacket
{

    private static final long serialVersionUID = -1462047376706075835L;

    private int height = 0;

    private int x = 0;

    private int y = 0;

    private int width = 0;

    private int windowId = 0;

    public ClientMapWindowPacket()
    {
        super( PacketType.Client.MAP_WINDOW.toString() );
    }

    public ClientMapWindowPacket( int windowId, int x, int y, int width, int height )
    {
        super( PacketType.Client.MAP_WINDOW.toString() );
        this.windowId = windowId;
        this.x = x;
        this.y = y;
        this.width = width;
        this.height = height;
    }

    public int getWindowId()
    {
        return windowId;
    }

    public int getX()
    {
        return x;
    }

    public int getY()
    {
        return y;
    }

    public int getWidth()
    {
        return width;
    }

    public int getHeight()
    {
        return height;
    }

    @Override
    public void packPacket( Collection<Object> packetData )
    {
        packetData.add( getPacketType() );
        packetData.add( windowId );
        packetData.add( x );
        packetData.add( y );
        packetData.add( width );
        packetData.add( height );
    }

}
