/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.packets.client;

import java.util.Collection;
import java.util.Date;

import org.dussan.vaadin.dvirtual.xpra.packets.ClientPacket;
import org.dussan.vaadin.dvirtual.xpra.packets.PacketType;
import org.dussan.vaadin.dvirtual.xpra.packets.server.ServerPingPacket;

public class ClientPingEchoPacket
    extends ClientPacket
{

    private static final long serialVersionUID = 8727983319793767228L;

    private long timestamp = 0;

    private long l1 = 0;

    private long l2 = 0;

    private long l3 = 0;

    private int serverLatency = 0;

    public ClientPingEchoPacket()
    {
        super( PacketType.Client.PING_ECHO.toString() );
    }

    public ClientPingEchoPacket( ServerPingPacket packet )
    {
        super( PacketType.Client.PING_ECHO.toString() );
        timestamp = packet.getTimestamp();
    }

    public long getL1()
    {
        return l1;
    }

    public long getL2()
    {
        return l2;
    }

    public long getL3()
    {
        return l3;
    }

    public int getServerLatency()
    {
        return serverLatency;
    }

    public long getTimestamp()
    {
        return timestamp == 0 ? new Date().getTime() : timestamp;
    }

    @Override
    public void packPacket( Collection<Object> packetData )
    {
        packetData.add( getPacketType() );
        packetData.add( getTimestamp() );
        packetData.add( getL1() );
        packetData.add( getL2() );
        packetData.add( getL3() );
        packetData.add( getServerLatency() );
    }

}
